@@ -57,7 +57,7 @@ has 'snapshot_id'	=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'status'		=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'volume_id'		=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'start_time'	=> ( is => 'ro', isa => 'Str', required => 1 );
-has 'progress'		=> ( is => 'ro', isa => 'Str', required => 1 );
+has 'progress'		=> ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 has 'owner_id'		=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'volume_size'	=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'description'	=> ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
